# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	A C library for portable packet creation and injection
Name:		libnet
Version:	1.3
Release:	4.0.cf.%{__distinit}%{__distvers}
License:	BSD-2-Clause
URL:		https://github.com/libnet/libnet
Source0:	https://github.com/libnet/libnet/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch0:		libnet-1.2-sample-include.patch
Patch1:		libnet-config.patch
BuildRequires:	coreutils
BuildRequires:	doxygen
BuildRequires:	gcc
BuildRequires:	graphviz
BuildRequires:	make
BuildRequires:	sed
BuildRequires:	/usr/bin/pod2man

%description
Libnet is an API to help with the construction and handling of network
packets. It provides a portable framework for low-level network packet
writing and handling (use libnet in conjunction with libpcap and you can
write some really cool stuff). Libnet includes packet creation at the IP
layer and at the link layer as well as a host of supplementary and
complementary functionality.

%package devel
Summary:	Development files for the libnet library
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	pkgconfig

%description devel
The libnet-devel package includes header files and libraries necessary
for developing programs which use the libnet library. Libnet is very handy
with which to write network tools and network test code. See the man-page
and sample test code for more detailed information.

%package doc
Summary:	Documentation files for the libnet library
BuildArch:	noarch

%description doc
Libnet is an API to help with the construction and handling of network
packets. It provides a portable framework for low-level network packet
writing and handling. This package contains the API documentation for
developing applications that use libnet.

%prep
%setup -q

# Avoid library soname bump (https://github.com/libnet/libnet/issues/115)
sed -e 's/-version-info 9:0:0/-version-info 9:0:8/' -i src/Makefile.{am,in}

# Fix up header file inclusion in sample code
%patch -P 0

# Fix multilib conflict with libnet-devel
%patch -P 1 -p1

%build
%configure
make %{?_smp_mflags} V=1

%install
%{make_install} INSTALL="install -p"

# Discard stuff we don't want packaged
rm %{buildroot}%{_libdir}/libnet.{a,la}
make -C sample clean
rm -rf sample/{win32,Makefile.{am,in}}

# Clean up for later usage in documentation
rm -rf %{buildroot}%{_defaultdocdir}

%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} <= 27)
# ldconfig replaced by RPM File Triggers from Fedora 28
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%files
%license LICENSE
%doc README.md ChangeLog.md
%{_libdir}/libnet.so.1
%{_libdir}/libnet.so.1.*

%files devel
%doc doc/MIGRATION.md doc/RAWSOCKET.md sample/
%{_bindir}/libnet-config
%{_libdir}/libnet.so
%{_libdir}/pkgconfig/libnet.pc
%{_includedir}/libnet.h
%{_includedir}/libnet/
%{_mandir}/man1/libnet-config.1*
%{_mandir}/man3/libnet.3*
%{_mandir}/man3/libnet-functions.3*
%{_mandir}/man3/libnet-macros.3*

%files doc
%doc doc/html/

%changelog
* Fri Jul 19 2024 Paul Howarth <paul@city-fan.org> - 1.3-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Thu Jan 25 2024 Paul Howarth <paul@city-fan.org> - 1.3-3.0.cf
- Re-rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild
  (see https://pagure.io/releng/issue/11888)

* Sat Jan 20 2024 Paul Howarth <paul@city-fan.org> - 1.3-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Oct  6 2023 Paul Howarth <paul@city-fan.org> - 1.3-1.0.cf
- Update to 1.3 (see ChangeLog.md for details)

* Thu Jul 20 2023 Paul Howarth <paul@city-fan.org> - 1.2-9.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jun 20 2023 Paul Howarth <paul@city-fan.org> - 1.2-8.0.cf
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Fri Jan 20 2023 Paul Howarth <paul@city-fan.org> - 1.2-7.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sun Jul 24 2022 Paul Howarth <paul@city-fan.org> - 1.2-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Fri Jan 21 2022 Paul Howarth <paul@city-fan.org> - 1.2-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jul 23 2021 Paul Howarth <paul@city-fan.org> - 1.2-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild
- Fix multilib conflict with libnet-devel
- Fix dist tags for Alma and Rocky Linux

* Thu Jan 28 2021 Paul Howarth <paul@city-fan.org> - 1.2-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Mon Jan  4 2021 Paul Howarth <paul@city-fan.org> - 1.2-1.0.cf
- Update to 1.2 (see ChangeLog.md for details)
- Avoid library soname bump (https://github.com/libnet/libnet/issues/115)
- Upstream moved from sourceforge to GitHub
- Add libnet-doc sub-package with HTML documentation
- Drop support for EOL distributions prior to F-19, EL-7:
  - UsrMove always true
  - Use %%license unconditionally

* Tue Jul 28 2020 Paul Howarth <paul@city-fan.org> - 1.1.6-20.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Fri Jan 31 2020 Paul Howarth <paul@city-fan.org> - 1.1.6-19.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jul 25 2019 Paul Howarth <paul@city-fan.org> - 1.1.6-18.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Tue Feb  5 2019 Paul Howarth <paul@city-fan.org> - 1.1.6-17.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Jul 16 2018 Paul Howarth <paul@city-fan.org> - 1.1.6-16.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Feb 19 2018 Paul Howarth <paul@city-fan.org> - 1.1.6-15.0.cf
- ldconfig replaced by RPM File Triggers from Fedora 28
- Specify all explicitly used build requirements

* Mon Aug 14 2017 Paul Howarth <paul@city-fan.org> - 1.1.6-14.0.cf
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sun Feb 12 2017 Paul Howarth <paul@city-fan.org> - 1.1.6-12.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Feb  5 2016 Paul Howarth <paul@city-fan.org> - 1.1.6-11.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Jun 21 2015 Paul Howarth <paul@city-fan.org> - 1.1.6-10.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Aug 19 2014 Paul Howarth <paul@city-fan.org> - 1.1.6-9.0.cf
- Use %%license where possible

* Wed Jun 11 2014 Paul Howarth <paul@city-fan.org> - 1.1.6-8.0.cf
- Drop %%defattr, redundant sice rpm 4.4

* Sat Dec 21 2013 Paul Howarth <paul@city-fan.org> - 1.1.6-7.0.cf
- Tighten run-time dependencies between sub-packages using %%{?_isa}

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> - 1.1.6-6.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Feb 24 2013 Paul Howarth <paul@city-fan.org> - 1.1.6-5.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> - 1.1.6-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Apr  2 2012 Paul Howarth <paul@city-fan.org> - 1.1.6-3.0.cf
- Add filesystem guard for UsrMove

* Sun Apr  1 2012 Paul Howarth <paul@city-fan.org> - 1.1.6-1.0.cf
- Update to 1.1.6 (see CHANGELOG for details)
- For F-17/RHEL-7 onwards, install to %%{_libdir} rather than /%%{_lib}
- Fix up sample header file in %%prep rather than %%install
- Upstream no longer ships doc/BUGS

* Sat Aug  6 2011 Paul Howarth <paul@city-fan.org> - 1.1.5-3.0.cf
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Feb 11 2011 Paul Howarth <paul@city-fan.org> - 1.1.5-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Dec 31 2010 Paul Howarth <paul@city-fan.org> - 1.1.5-1.0.cf
- Updated to 1.1.5 (see CHANGELOG for details)

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 1.1.4-5.0.cf
- Fix dist tag for RHEL-6 Beta

* Wed Feb 24 2010 Paul Howarth <paul@city-fan.org> - 1.1.4-4.0.cf
- Dist tag for Rawhide no longer needs special-casing

* Thu Aug 27 2009 Paul Howarth <paul@city-fan.org> - 1.1.4-3.0.cf
- Updated to 1.1.4
- Add dist tags
- Clean out old cruft
- Upstream development now at http://sourceforge.net/projects/libnet-dev/
- Split off -devel subpackage
- Install into /%%{_lib} for benefit of syslog type apps (#518150)
- Enable parallel build
- Maintain timestamps of untouched upstream files
- Add scriptlets to run ldconfig since the library is now shared, not static
- Add buildreq symlinks
- Fix header file location in sample code

* Mon Sep 20 2004 Paul Howarth <paul@city-fan.org> - 1.1.2.1
- Rewritten for 1.1.2.1

* Mon Dec 16 2002 Dag Wieers <dag@wieers.com> - 1.0.2
- Updated to 1.0.2a (1.1.0 does not work with 1.1.0)

* Thu Aug 02 2001 Dag Wieers <dag@wieers.com> - 1.0.1
- Initial package
